# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.custom_sandbox_data import CustomSandboxData


class TestCustomSandboxData(unittest.TestCase):
    """CustomSandboxData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CustomSandboxData:
        """Test CustomSandboxData
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `CustomSandboxData`
        """
        model = CustomSandboxData()
        if include_optional:
            return CustomSandboxData(
                accounts = [
                    moneykit.models.custom_sandbox_account.CustomSandboxAccount(
                        account_type = '', 
                        name = '', 
                        account_number = '', 
                        routing_number = '', )
                    ],
                owners = [
                    moneykit.models.owner.Owner(
                        names = [
                            ''
                            ], 
                        addresses = [
                            moneykit.models.address.Address(
                                city = '', 
                                country = '', 
                                postal_code = '', 
                                region = '', 
                                street = '', 
                                primary = True, )
                            ], 
                        phone_numbers = [
                            moneykit.models.phone_number.PhoneNumber(
                                number = '', 
                                primary = True, 
                                type = null, )
                            ], 
                        emails = [
                            moneykit.models.email.Email(
                                address = '', 
                                primary = True, )
                            ], )
                    ]
            )
        else:
            return CustomSandboxData(
                accounts = [
                    moneykit.models.custom_sandbox_account.CustomSandboxAccount(
                        account_type = '', 
                        name = '', 
                        account_number = '', 
                        routing_number = '', )
                    ],
        )
        """

    def testCustomSandboxData(self):
        """Test CustomSandboxData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool
from pydantic import Field

try:
    from typing import Self
except ImportError:
    from typing_extensions import Self


class MoneyKitConnectFeatures(BaseModel):
    """
    MoneyKitConnectFeatures
    """  # noqa: E501

    issue_reporter: Optional[StrictBool] = Field(
        default=False,
        description="If enabled, the user can report linking issues directly to MoneyKit via 'Report Issue' button.",
    )
    enable_money_id: Optional[StrictBool] = Field(
        default=False,
        description="If enabled, the user can register for, or login into, Money ID.",
    )
    duplicate_institution_warning: Optional[StrictBool] = Field(
        default=False,
        description="If enabled, the user will see a warning when trying to connect to an institution for which             they already have a connected link.",
    )
    duplicate_institution_rejected: Optional[StrictBool] = Field(
        default=False,
        description="If enabled, all institutions for which the user has a connected link will be hidden, so the user             will be unable to make another link to an institution to which they are already linked.",
    )
    connect_manually: Optional[StrictBool] = Field(
        default=False,
        description="If enabled, the user can click a button in the MoneyKit Connect SDK to connect manually if the institution they are looking for doesn't exist in our catalog.",
    )
    permit_only_one_account: Optional[StrictBool] = Field(
        default=False,
        description="If enabled, the user is allowed to grant permission only for one account.",
    )
    permit_only_depository_accounts: Optional[StrictBool] = Field(
        default=False,
        description="If enabled, the user is allowed to grant permission only for depository accounts.             If there are no depository accounts, the linking process will fail.",
    )
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = [
        "issue_reporter",
        "enable_money_id",
        "duplicate_institution_warning",
        "duplicate_institution_rejected",
        "connect_manually",
        "permit_only_one_account",
        "permit_only_depository_accounts",
    ]

    model_config = {"populate_by_name": True, "validate_assignment": True}

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of MoneyKitConnectFeatures from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
                "additional_properties",
            },
            exclude_none=True,
        )
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of MoneyKitConnectFeatures from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "issue_reporter": obj.get("issue_reporter")
                if obj.get("issue_reporter") is not None
                else False,
                "enable_money_id": obj.get("enable_money_id")
                if obj.get("enable_money_id") is not None
                else False,
                "duplicate_institution_warning": obj.get(
                    "duplicate_institution_warning"
                )
                if obj.get("duplicate_institution_warning") is not None
                else False,
                "duplicate_institution_rejected": obj.get(
                    "duplicate_institution_rejected"
                )
                if obj.get("duplicate_institution_rejected") is not None
                else False,
                "connect_manually": obj.get("connect_manually")
                if obj.get("connect_manually") is not None
                else False,
                "permit_only_one_account": obj.get("permit_only_one_account")
                if obj.get("permit_only_one_account") is not None
                else False,
                "permit_only_depository_accounts": obj.get(
                    "permit_only_depository_accounts"
                )
                if obj.get("permit_only_depository_accounts") is not None
                else False,
            }
        )
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.account_response import AccountResponse


class TestAccountResponse(unittest.TestCase):
    """AccountResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AccountResponse:
        """Test AccountResponse
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `AccountResponse`
        """
        model = AccountResponse()
        if include_optional:
            return AccountResponse(
                account_id = '',
                account_type = '',
                name = '',
                nickname = '',
                account_mask = '',
                balances = moneykit.models.account_balances.AccountBalances(
                    currency = '', 
                    available = 1.337, 
                    current = 1.337, 
                    limit = 1.337, 
                    balance_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                original_id = '',
                closed = True
            )
        else:
            return AccountResponse(
                account_id = '',
                account_type = '',
                name = '',
                balances = moneykit.models.account_balances.AccountBalances(
                    currency = '', 
                    available = 1.337, 
                    current = 1.337, 
                    limit = 1.337, 
                    balance_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
        )
        """

    def testAccountResponse(self):
        """Test AccountResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.app_client_response import AppClientResponse


class TestAppClientResponse(unittest.TestCase):
    """AppClientResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AppClientResponse:
        """Test AppClientResponse
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `AppClientResponse`
        """
        model = AppClientResponse()
        if include_optional:
            return AppClientResponse(
                client_id = '',
                client_name = '',
                scope = '',
                app = moneykit.models.app_response.AppResponse(
                    app_id = '', 
                    name = '', 
                    id = '', 
                    app_name = '', ),
                disabled_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return AppClientResponse(
                client_id = '',
                client_name = '',
                scope = '',
                app = moneykit.models.app_response.AppResponse(
                    app_id = '', 
                    name = '', 
                    id = '', 
                    app_name = '', ),
        )
        """

    def testAppClientResponse(self):
        """Test AppClientResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.transaction_import_data import TransactionImportData


class TestTransactionImportData(unittest.TestCase):
    """TransactionImportData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TransactionImportData:
        """Test TransactionImportData
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `TransactionImportData`
        """
        model = TransactionImportData()
        if include_optional:
            return TransactionImportData(
                account_id = '',
                transaction_id = '',
                amount = '',
                var_date = None,
                description = '',
                type = ''
            )
        else:
            return TransactionImportData(
                account_id = '',
                amount = '',
                var_date = None,
        )
        """

    def testTransactionImportData(self):
        """Test TransactionImportData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.api.webhooks_api import WebhooksApi


class TestWebhooksApi(unittest.TestCase):
    """WebhooksApi unit test stubs"""

    def setUp(self) -> None:
        self.api = WebhooksApi()

    def tearDown(self) -> None:
        pass

    def test_trigger_test_link_webhook_event(self) -> None:
        """Test case for trigger_test_link_webhook_event

        /webhooks/test/link/{id}
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.response401_get_accounts_links_id_accounts_get import (
    Response401GetAccountsLinksIdAccountsGet,
)


class TestResponse401GetAccountsLinksIdAccountsGet(unittest.TestCase):
    """Response401GetAccountsLinksIdAccountsGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(
        self, include_optional
    ) -> Response401GetAccountsLinksIdAccountsGet:
        """Test Response401GetAccountsLinksIdAccountsGet
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `Response401GetAccountsLinksIdAccountsGet`
        """
        model = Response401GetAccountsLinksIdAccountsGet()
        if include_optional:
            return Response401GetAccountsLinksIdAccountsGet(
                error_code = link_error.unauthorized_access,
                error_message = None,
                documentation_url = None
            )
        else:
            return Response401GetAccountsLinksIdAccountsGet(
                error_message = None,
        )
        """

    def testResponse401GetAccountsLinksIdAccountsGet(self):
        """Test Response401GetAccountsLinksIdAccountsGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.transactions_product_settings import TransactionsProductSettings


class TestTransactionsProductSettings(unittest.TestCase):
    """TransactionsProductSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TransactionsProductSettings:
        """Test TransactionsProductSettings
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `TransactionsProductSettings`
        """
        model = TransactionsProductSettings()
        if include_optional:
            return TransactionsProductSettings(
                required = True,
                require_permission = True,
                prefetch = True,
                reason = ''
            )
        else:
            return TransactionsProductSettings(
        )
        """

    def testTransactionsProductSettings(self):
        """Test TransactionsProductSettings"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import json
import re  # noqa: F401
from enum import Enum


try:
    from typing import Self
except ImportError:
    from typing_extensions import Self


class BudPrimaryCategory(str, Enum):
    """
    An enumeration.
    """

    """
    allowed enum values
    """
    BANKING = "banking"
    BORROWING_AND_LOANS = "borrowing_and_loans"
    CHARITY = "charity"
    DEPENDENT_COSTS = "dependent_costs"
    EDUCATION = "education"
    ENTERTAINMENT = "entertainment"
    EXPENSES = "expenses"
    FOOD_AND_DRINK = "food_and_drink"
    GAMBLING_AND_LOTTERIES = "gambling_and_lotteries"
    GENERAL = "general"
    HEALTH_AND_PERSONAL_CARE = "health_and_personal_care"
    HOME = "home"
    INCOME = "income"
    INSURANCE = "insurance"
    MEDIA_AND_TELECOMS = "media_and_telecoms"
    MORTGAGE_AND_RENT = "mortgage_and_rent"
    PENSIONS_SAVINGS_AND_INVESTMENTS = "pensions_savings_and_investments"
    SHOPPING = "shopping"
    TAXES = "taxes"
    TRANSFERS = "transfers"
    TRANSPORT = "transport"
    TRAVEL = "travel"
    UTILITIES = "utilities"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of BudPrimaryCategory from a JSON string"""
        return cls(json.loads(json_str))



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.link_products import LinkProducts


class TestLinkProducts(unittest.TestCase):
    """LinkProducts unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LinkProducts:
        """Test LinkProducts
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `LinkProducts`
        """
        model = LinkProducts()
        if include_optional:
            return LinkProducts(
                accounts = moneykit.models.link_product_response.LinkProductResponse(
                    refreshed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    last_attempted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    error_code = null, 
                    error_message = '', 
                    unavailable = '', 
                    settings = null, ),
                account_numbers = moneykit.models.link_product_response.LinkProductResponse(
                    refreshed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    last_attempted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    error_code = null, 
                    error_message = '', 
                    unavailable = '', 
                    settings = null, ),
                identity = moneykit.models.link_product_response.LinkProductResponse(
                    refreshed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    last_attempted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    error_code = null, 
                    error_message = '', 
                    unavailable = '', 
                    settings = null, ),
                transactions = moneykit.models.transactions_link_product.TransactionsLinkProduct(
                    refreshed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    last_attempted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    error_code = null, 
                    error_message = '', 
                    unavailable = '', 
                    settings = null, 
                    has_history = True, ),
                investments = moneykit.models.link_product_response.LinkProductResponse(
                    refreshed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    last_attempted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    error_code = null, 
                    error_message = '', 
                    unavailable = '', 
                    settings = null, ),
                enrichment = moneykit.models.link_product_response.LinkProductResponse(
                    refreshed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    last_attempted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    error_code = null, 
                    error_message = '', 
                    unavailable = '', 
                    settings = null, )
            )
        else:
            return LinkProducts(
        )
        """

    def testLinkProducts(self):
        """Test LinkProducts"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.body import Body


class TestBody(unittest.TestCase):
    """Body unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Body:
        """Test Body
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `Body`
        """
        model = Body()
        if include_optional:
            return Body(
                webhook_major_version = 1,
                webhook_minor_version = 0,
                webhook_idempotency_key = None,
                webhook_timestamp = None,
                link_id = None,
                link_tags = None,
                webhook_event = transactions.updates_available,
                state = 'pending',
                error = 'system_error',
                error_message = None,
                product = 'accounts',
                state_changed_at = None,
                has_history = None
            )
        else:
            return Body(
                webhook_idempotency_key = None,
                webhook_timestamp = None,
                link_id = None,
                link_tags = None,
                state = 'pending',
                product = 'accounts',
                state_changed_at = None,
        )
        """

    def testBody(self):
        """Test Body"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.import_link_request import ImportLinkRequest


class TestImportLinkRequest(unittest.TestCase):
    """ImportLinkRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ImportLinkRequest:
        """Test ImportLinkRequest
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `ImportLinkRequest`
        """
        model = ImportLinkRequest()
        if include_optional:
            return ImportLinkRequest(
                customer_user = moneykit.models.customer_user.CustomerUser(
                    id = '0123', 
                    email = null, 
                    phone = null, ),
                provider = 'moneykit',
                institution_id = '',
                accounts = [
                    moneykit.models.account_import_data.AccountImportData(
                        account_id = '', 
                        name = '', 
                        nickname = '', 
                        type = '', 
                        mask = '', 
                        balances = null, )
                    ],
                transactions = [
                    moneykit.models.transaction_import_data.TransactionImportData(
                        account_id = '', 
                        transaction_id = '', 
                        amount = '', 
                        date = null, 
                        description = '', 
                        type = '', )
                    ]
            )
        else:
            return ImportLinkRequest(
                customer_user = moneykit.models.customer_user.CustomerUser(
                    id = '0123', 
                    email = null, 
                    phone = null, ),
                institution_id = '',
                accounts = [
                    moneykit.models.account_import_data.AccountImportData(
                        account_id = '', 
                        name = '', 
                        nickname = '', 
                        type = '', 
                        mask = '', 
                        balances = null, )
                    ],
                transactions = [
                    moneykit.models.transaction_import_data.TransactionImportData(
                        account_id = '', 
                        transaction_id = '', 
                        amount = '', 
                        date = null, 
                        description = '', 
                        type = '', )
                    ],
        )
        """

    def testImportLinkRequest(self):
        """Test ImportLinkRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.transaction_response import TransactionResponse


class TestTransactionResponse(unittest.TestCase):
    """TransactionResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TransactionResponse:
        """Test TransactionResponse
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `TransactionResponse`
        """
        model = TransactionResponse()
        if include_optional:
            return TransactionResponse(
                transaction_id = '',
                account_id = '',
                amount = '',
                type = 'credit',
                currency = '',
                var_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                description = '',
                raw_description = '',
                pending = True,
                category = '',
                enrichment = moneykit.models.transaction_enrichment_response.TransactionEnrichmentResponse(
                    category = moneykit.models.transaction_category_response.TransactionCategoryResponse(
                        value = '', 
                        confidence = 56, ), 
                    subcategory = moneykit.models.transaction_subcategory_response.TransactionSubcategoryResponse(
                        value = '', 
                        confidence = 56, ), 
                    merchant = moneykit.models.transaction_merchant_response.TransactionMerchantResponse(
                        id = '', 
                        name = '', 
                        logo = '', 
                        confidence = 56, ), 
                    processor = moneykit.models.transaction_processor_response.TransactionProcessorResponse(
                        id = '', 
                        name = '', 
                        logo = '', 
                        confidence = 56, ), 
                    recurrence = moneykit.models.transaction_recurrence_response.TransactionRecurrenceResponse(
                        frequency = '', 
                        next_predicted_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), ), ),
                original_id = ''
            )
        else:
            return TransactionResponse(
                transaction_id = '',
                account_id = '',
                amount = '',
                type = 'credit',
                currency = '',
                var_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(),
                pending = True,
        )
        """

    def testTransactionResponse(self):
        """Test TransactionResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.account_with_account_numbers_legacy20230218 import (
    AccountWithAccountNumbersLegacy20230218,
)


class TestAccountWithAccountNumbersLegacy20230218(unittest.TestCase):
    """AccountWithAccountNumbersLegacy20230218 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(
        self, include_optional
    ) -> AccountWithAccountNumbersLegacy20230218:
        """Test AccountWithAccountNumbersLegacy20230218
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `AccountWithAccountNumbersLegacy20230218`
        """
        model = AccountWithAccountNumbersLegacy20230218()
        if include_optional:
            return AccountWithAccountNumbersLegacy20230218(
                account_id = '',
                account_type = '',
                name = '',
                nickname = '',
                account_mask = '',
                balances = moneykit.models.account_balances.AccountBalances(
                    currency = '', 
                    available = 1.337, 
                    current = 1.337, 
                    limit = 1.337, 
                    balance_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                original_id = '',
                closed = True,
                numbers = moneykit.models.account_numbers_legacy_2023_02_18.AccountNumbersLegacy_2023_02_18(
                    ach = [
                        moneykit.models.ach_number.AchNumber(
                            account_number = '', 
                            routing_number = '', 
                            wire_routing_number = '', )
                        ], 
                    eft = [
                        moneykit.models.eft_number.EftNumber(
                            account_number = '', 
                            institution_number = '', 
                            branch_number = '', )
                        ], 
                    bacs = [
                        moneykit.models.bacs_number.BacsNumber(
                            account_number = '', 
                            sort_code = '', )
                        ], 
                    international = [
                        moneykit.models.international_number.InternationalNumber(
                            iban = '', 
                            bic = '', )
                        ], )
            )
        else:
            return AccountWithAccountNumbersLegacy20230218(
                account_id = '',
                account_type = '',
                name = '',
                balances = moneykit.models.account_balances.AccountBalances(
                    currency = '', 
                    available = 1.337, 
                    current = 1.337, 
                    limit = 1.337, 
                    balance_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                numbers = moneykit.models.account_numbers_legacy_2023_02_18.AccountNumbersLegacy_2023_02_18(
                    ach = [
                        moneykit.models.ach_number.AchNumber(
                            account_number = '', 
                            routing_number = '', 
                            wire_routing_number = '', )
                        ], 
                    eft = [
                        moneykit.models.eft_number.EftNumber(
                            account_number = '', 
                            institution_number = '', 
                            branch_number = '', )
                        ], 
                    bacs = [
                        moneykit.models.bacs_number.BacsNumber(
                            account_number = '', 
                            sort_code = '', )
                        ], 
                    international = [
                        moneykit.models.international_number.InternationalNumber(
                            iban = '', 
                            bic = '', )
                        ], ),
        )
        """

    def testAccountWithAccountNumbersLegacy20230218(self):
        """Test AccountWithAccountNumbersLegacy20230218"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.create_access_token_response import CreateAccessTokenResponse


class TestCreateAccessTokenResponse(unittest.TestCase):
    """CreateAccessTokenResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateAccessTokenResponse:
        """Test CreateAccessTokenResponse
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `CreateAccessTokenResponse`
        """
        model = CreateAccessTokenResponse()
        if include_optional:
            return CreateAccessTokenResponse(
                access_token = '',
                token_type = '',
                expires_in = 56
            )
        else:
            return CreateAccessTokenResponse(
                access_token = '',
                token_type = '',
                expires_in = 56,
        )
        """

    def testCreateAccessTokenResponse(self):
        """Test CreateAccessTokenResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictStr
from pydantic import Field
from moneykit.models.account_balances import AccountBalances

try:
    from typing import Self
except ImportError:
    from typing_extensions import Self


class AccountImportData(BaseModel):
    """
    AccountImportData
    """  # noqa: E501

    account_id: StrictStr = Field(
        description="Your internal ID for this account.  Must be unique within the imported account batch."
    )
    name: StrictStr = Field(
        description="The account name.  This value may change if synced with a data provider later."
    )
    nickname: Optional[StrictStr] = Field(
        default=None,
        description="The account nickname.  This value may change if synced with a data provider later.",
    )
    type: StrictStr = Field(
        description="The account type.  It can have any initial value but it will be converted to a MoneyKit         account type (see <a href=/pages/account_types>Account Types</a>) upon output.  The account may change types if it is         synced with a data provider later."
    )
    mask: Optional[StrictStr] = Field(
        default=None,
        description="The last four characters (usually digits) of the account number.  This field can be         omitted, but you are strongly encouraged to supply it because it is the most important factor for properly         connecting new data to this account if it is synced with a data provider later.",
    )
    balances: AccountBalances
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = [
        "account_id",
        "name",
        "nickname",
        "type",
        "mask",
        "balances",
    ]

    model_config = {"populate_by_name": True, "validate_assignment": True}

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AccountImportData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
                "additional_properties",
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of balances
        if self.balances:
            _dict["balances"] = self.balances.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of AccountImportData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "account_id": obj.get("account_id"),
                "name": obj.get("name"),
                "nickname": obj.get("nickname"),
                "type": obj.get("type"),
                "mask": obj.get("mask"),
                "balances": AccountBalances.from_dict(obj.get("balances"))
                if obj.get("balances") is not None
                else None,
            }
        )
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.transactions_link_product import TransactionsLinkProduct


class TestTransactionsLinkProduct(unittest.TestCase):
    """TransactionsLinkProduct unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TransactionsLinkProduct:
        """Test TransactionsLinkProduct
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `TransactionsLinkProduct`
        """
        model = TransactionsLinkProduct()
        if include_optional:
            return TransactionsLinkProduct(
                refreshed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                last_attempted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                error_code = 'rate_limit',
                error_message = '',
                unavailable = '',
                settings = moneykit.models.transactions_product_settings.TransactionsProductSettings(
                    required = True, 
                    require_permission = True, 
                    prefetch = True, 
                    reason = '', ),
                has_history = True
            )
        else:
            return TransactionsLinkProduct(
                has_history = True,
        )
        """

    def testTransactionsLinkProduct(self):
        """Test TransactionsLinkProduct"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.create_link_session_request import CreateLinkSessionRequest


class TestCreateLinkSessionRequest(unittest.TestCase):
    """CreateLinkSessionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateLinkSessionRequest:
        """Test CreateLinkSessionRequest
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `CreateLinkSessionRequest`
        """
        model = CreateLinkSessionRequest()
        if include_optional:
            return CreateLinkSessionRequest(
                settings = moneykit.models.link_session_setting_overrides.LinkSessionSettingOverrides(
                    providers = [
                        'moneykit'
                        ], 
                    products = null, 
                    countries = [
                        'US'
                        ], ),
                customer_user = moneykit.models.customer_user.CustomerUser(
                    id = '0123', 
                    email = null, 
                    phone = null, ),
                existing_link_id = '',
                institution_id = '',
                redirect_uri = '0',
                webhook = '0',
                link_tags = [
                    ''
                    ],
                connect_features = moneykit.models.money_kit_connect_features.MoneyKitConnectFeatures(
                    issue_reporter = True, 
                    enable_money_id = True, 
                    duplicate_institution_warning = True, 
                    duplicate_institution_rejected = True, 
                    connect_manually = True, 
                    permit_only_one_account = True, 
                    permit_only_depository_accounts = True, ),
                custom_sandbox_data = moneykit.models.custom_sandbox_data.CustomSandboxData(
                    accounts = [
                        moneykit.models.custom_sandbox_account.CustomSandboxAccount(
                            account_type = '', 
                            name = '', 
                            account_number = '', 
                            routing_number = '', )
                        ], 
                    owners = [
                        moneykit.models.owner.Owner(
                            names = [
                                ''
                                ], 
                            addresses = [
                                moneykit.models.address.Address(
                                    city = '', 
                                    country = '', 
                                    postal_code = '', 
                                    region = '', 
                                    street = '', 
                                    primary = True, )
                                ], 
                            phone_numbers = [
                                moneykit.models.phone_number.PhoneNumber(
                                    number = '', 
                                    primary = True, 
                                    type = null, )
                                ], 
                            emails = [
                                moneykit.models.email.Email(
                                    address = '', 
                                    primary = True, )
                                ], )
                        ], )
            )
        else:
            return CreateLinkSessionRequest(
                customer_user = moneykit.models.customer_user.CustomerUser(
                    id = '0123', 
                    email = null, 
                    phone = null, ),
                redirect_uri = '0',
        )
        """

    def testCreateLinkSessionRequest(self):
        """Test CreateLinkSessionRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.get_links_response import GetLinksResponse


class TestGetLinksResponse(unittest.TestCase):
    """GetLinksResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetLinksResponse:
        """Test GetLinksResponse
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `GetLinksResponse`
        """
        model = GetLinksResponse()
        if include_optional:
            return GetLinksResponse(
                links = [
                    moneykit.models.get_links_link.GetLinksLink(
                        link_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
                next_cursor = ''
            )
        else:
            return GetLinksResponse(
        )
        """

    def testGetLinksResponse(self):
        """Test GetLinksResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.owner import Owner


class TestOwner(unittest.TestCase):
    """Owner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Owner:
        """Test Owner
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `Owner`
        """
        model = Owner()
        if include_optional:
            return Owner(
                names = [
                    ''
                    ],
                addresses = [
                    moneykit.models.address.Address(
                        city = '', 
                        country = '', 
                        postal_code = '', 
                        region = '', 
                        street = '', 
                        primary = True, )
                    ],
                phone_numbers = [
                    moneykit.models.phone_number.PhoneNumber(
                        number = '', 
                        primary = True, 
                        type = null, )
                    ],
                emails = [
                    moneykit.models.email.Email(
                        address = '', 
                        primary = True, )
                    ]
            )
        else:
            return Owner(
                names = [
                    ''
                    ],
                addresses = [
                    moneykit.models.address.Address(
                        city = '', 
                        country = '', 
                        postal_code = '', 
                        region = '', 
                        street = '', 
                        primary = True, )
                    ],
                phone_numbers = [
                    moneykit.models.phone_number.PhoneNumber(
                        number = '', 
                        primary = True, 
                        type = null, )
                    ],
                emails = [
                    moneykit.models.email.Email(
                        address = '', 
                        primary = True, )
                    ],
        )
        """

    def testOwner(self):
        """Test Owner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.link_common import LinkCommon


class TestLinkCommon(unittest.TestCase):
    """LinkCommon unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LinkCommon:
        """Test LinkCommon
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `LinkCommon`
        """
        model = LinkCommon()
        if include_optional:
            return LinkCommon(
                link_id = '',
                institution_id = '',
                institution_name = '',
                institution_avatar = '',
                state = 'connecting',
                error_code = 'system_error',
                last_synced_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                provider = 'moneykit',
                link_tags = [
                    ''
                    ],
                tags = [
                    ''
                    ],
                webhook = '',
                products = moneykit.models.link_products.LinkProducts(
                    accounts = moneykit.models.link_product_response.LinkProductResponse(
                        refreshed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_attempted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        error_code = null, 
                        error_message = '', 
                        unavailable = '', 
                        settings = null, ), 
                    account_numbers = moneykit.models.link_product_response.LinkProductResponse(
                        refreshed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_attempted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        error_code = null, 
                        error_message = '', 
                        unavailable = '', 
                        settings = null, ), 
                    identity = , 
                    transactions = moneykit.models.transactions_link_product.TransactionsLinkProduct(
                        refreshed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_attempted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        error_code = null, 
                        error_message = '', 
                        unavailable = '', 
                        settings = null, 
                        has_history = True, ), 
                    investments = , 
                    enrichment = , ),
                available_products = [
                    'accounts'
                    ]
            )
        else:
            return LinkCommon(
                link_id = '',
                institution_id = '',
                institution_name = '',
                institution_avatar = '',
                state = 'connecting',
                provider = 'moneykit',
                products = moneykit.models.link_products.LinkProducts(
                    accounts = moneykit.models.link_product_response.LinkProductResponse(
                        refreshed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_attempted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        error_code = null, 
                        error_message = '', 
                        unavailable = '', 
                        settings = null, ), 
                    account_numbers = moneykit.models.link_product_response.LinkProductResponse(
                        refreshed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_attempted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        error_code = null, 
                        error_message = '', 
                        unavailable = '', 
                        settings = null, ), 
                    identity = , 
                    transactions = moneykit.models.transactions_link_product.TransactionsLinkProduct(
                        refreshed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        last_attempted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        error_code = null, 
                        error_message = '', 
                        unavailable = '', 
                        settings = null, 
                        has_history = True, ), 
                    investments = , 
                    enrichment = , ),
                available_products = [
                    'accounts'
                    ],
        )
        """

    def testLinkCommon(self):
        """Test LinkCommon"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.transaction_enrichment_response import (
    TransactionEnrichmentResponse,
)


class TestTransactionEnrichmentResponse(unittest.TestCase):
    """TransactionEnrichmentResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TransactionEnrichmentResponse:
        """Test TransactionEnrichmentResponse
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `TransactionEnrichmentResponse`
        """
        model = TransactionEnrichmentResponse()
        if include_optional:
            return TransactionEnrichmentResponse(
                category = moneykit.models.transaction_category_response.TransactionCategoryResponse(
                    value = '', 
                    confidence = 56, ),
                subcategory = moneykit.models.transaction_subcategory_response.TransactionSubcategoryResponse(
                    value = '', 
                    confidence = 56, ),
                merchant = moneykit.models.transaction_merchant_response.TransactionMerchantResponse(
                    id = '', 
                    name = '', 
                    logo = '', 
                    confidence = 56, ),
                processor = moneykit.models.transaction_processor_response.TransactionProcessorResponse(
                    id = '', 
                    name = '', 
                    logo = '', 
                    confidence = 56, ),
                recurrence = moneykit.models.transaction_recurrence_response.TransactionRecurrenceResponse(
                    frequency = '', 
                    next_predicted_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), )
            )
        else:
            return TransactionEnrichmentResponse(
                category = moneykit.models.transaction_category_response.TransactionCategoryResponse(
                    value = '', 
                    confidence = 56, ),
        )
        """

    def testTransactionEnrichmentResponse(self):
        """Test TransactionEnrichmentResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.api.links_api import LinksApi


class TestLinksApi(unittest.TestCase):
    """LinksApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LinksApi()

    def tearDown(self) -> None:
        pass

    def test_delete_link(self) -> None:
        """Test case for delete_link

        /links/{id}
        """
        pass

    def test_get_link(self) -> None:
        """Test case for get_link

        /links/{id}
        """
        pass

    def test_get_links(self) -> None:
        """Test case for get_links

        /links
        """
        pass

    def test_get_user_links(self) -> None:
        """Test case for get_user_links

        /users/{id}/links
        """
        pass

    def test_import_link(self) -> None:
        """Test case for import_link

        /links/import
        """
        pass

    def test_import_transactions(self) -> None:
        """Test case for import_transactions

        /links/{id}/import/transactions
        """
        pass

    def test_reset_link(self) -> None:
        """Test case for reset_link

        /links/{id}/reset
        """
        pass

    def test_update_link(self) -> None:
        """Test case for update_link

        /links/{id}
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.get_user_links_response import GetUserLinksResponse


class TestGetUserLinksResponse(unittest.TestCase):
    """GetUserLinksResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetUserLinksResponse:
        """Test GetUserLinksResponse
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `GetUserLinksResponse`
        """
        model = GetUserLinksResponse()
        if include_optional:
            return GetUserLinksResponse(
                links = {
                    'key' : moneykit.models.link_common.LinkCommon(
                        link_id = '', 
                        institution_id = '', 
                        institution_name = '', 
                        institution_avatar = '', 
                        state = null, 
                        error_code = null, 
                        last_synced_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        provider = null, 
                        link_tags = [
                            ''
                            ], 
                        tags = [
                            ''
                            ], 
                        webhook = '', 
                        products = null, 
                        available_products = [
                            'accounts'
                            ], )
                    }
            )
        else:
            return GetUserLinksResponse(
                links = {
                    'key' : moneykit.models.link_common.LinkCommon(
                        link_id = '', 
                        institution_id = '', 
                        institution_name = '', 
                        institution_avatar = '', 
                        state = null, 
                        error_code = null, 
                        last_synced_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        provider = null, 
                        link_tags = [
                            ''
                            ], 
                        tags = [
                            ''
                            ], 
                        webhook = '', 
                        products = null, 
                        available_products = [
                            'accounts'
                            ], )
                    },
        )
        """

    def testGetUserLinksResponse(self):
        """Test GetUserLinksResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import json
import re  # noqa: F401
from enum import Enum


try:
    from typing import Self
except ImportError:
    from typing_extensions import Self


class PublicLinkState(str, Enum):
    """
    An enumeration.
    """

    """
    allowed enum values
    """
    CONNECTING = "connecting"
    AWAITING_TOKEN_EXCHANGE = "awaiting_token_exchange"
    CONNECTED = "connected"
    DELETED = "deleted"
    ERROR = "error"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of PublicLinkState from a JSON string"""
        return cls(json.loads(json_str))



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.account_numbers_legacy20230218 import AccountNumbersLegacy20230218


class TestAccountNumbersLegacy20230218(unittest.TestCase):
    """AccountNumbersLegacy20230218 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AccountNumbersLegacy20230218:
        """Test AccountNumbersLegacy20230218
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `AccountNumbersLegacy20230218`
        """
        model = AccountNumbersLegacy20230218()
        if include_optional:
            return AccountNumbersLegacy20230218(
                ach = [
                    moneykit.models.ach_number.AchNumber(
                        account_number = '', 
                        routing_number = '', 
                        wire_routing_number = '', )
                    ],
                eft = [
                    moneykit.models.eft_number.EftNumber(
                        account_number = '', 
                        institution_number = '', 
                        branch_number = '', )
                    ],
                bacs = [
                    moneykit.models.bacs_number.BacsNumber(
                        account_number = '', 
                        sort_code = '', )
                    ],
                international = [
                    moneykit.models.international_number.InternationalNumber(
                        iban = '', 
                        bic = '', )
                    ]
            )
        else:
            return AccountNumbersLegacy20230218(
                ach = [
                    moneykit.models.ach_number.AchNumber(
                        account_number = '', 
                        routing_number = '', 
                        wire_routing_number = '', )
                    ],
                eft = [
                    moneykit.models.eft_number.EftNumber(
                        account_number = '', 
                        institution_number = '', 
                        branch_number = '', )
                    ],
                bacs = [
                    moneykit.models.bacs_number.BacsNumber(
                        account_number = '', 
                        sort_code = '', )
                    ],
                international = [
                    moneykit.models.international_number.InternationalNumber(
                        iban = '', 
                        bic = '', )
                    ],
        )
        """

    def testAccountNumbersLegacy20230218(self):
        """Test AccountNumbersLegacy20230218"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.account_balances import AccountBalances


class TestAccountBalances(unittest.TestCase):
    """AccountBalances unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AccountBalances:
        """Test AccountBalances
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `AccountBalances`
        """
        model = AccountBalances()
        if include_optional:
            return AccountBalances(
                currency = '',
                available = 1.337,
                current = 1.337,
                limit = 1.337,
                balance_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return AccountBalances(
        )
        """

    def testAccountBalances(self):
        """Test AccountBalances"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.get_investment_transactions_response import (
    GetInvestmentTransactionsResponse,
)


class TestGetInvestmentTransactionsResponse(unittest.TestCase):
    """GetInvestmentTransactionsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetInvestmentTransactionsResponse:
        """Test GetInvestmentTransactionsResponse
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `GetInvestmentTransactionsResponse`
        """
        model = GetInvestmentTransactionsResponse()
        if include_optional:
            return GetInvestmentTransactionsResponse(
                total = 56,
                page = 56,
                size = 56,
                investment_transactions = [
                    moneykit.models.investment_transaction_response.InvestmentTransactionResponse(
                        investment_transaction_id = '', 
                        account_id = '', 
                        amount = '', 
                        date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        description = '', 
                        type = '', 
                        fees = '', 
                        forex_rate = '', 
                        price = '', 
                        quantity = '', 
                        security_id = '', )
                    ],
                securities = [
                    moneykit.models.security_response.SecurityResponse(
                        security_id = '', 
                        name = '', 
                        type = '', 
                        currency = '', 
                        ticker = '', 
                        isin = '', 
                        sedol = '', 
                        close_price = '', 
                        close_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), )
                    ],
                accounts = [
                    moneykit.models.account_response.AccountResponse(
                        account_id = '', 
                        account_type = '', 
                        name = '', 
                        nickname = '', 
                        account_mask = '', 
                        balances = null, 
                        original_id = '', 
                        closed = True, )
                    ],
                link = moneykit.models.link_common.LinkCommon(
                    link_id = '', 
                    institution_id = '', 
                    institution_name = '', 
                    institution_avatar = '', 
                    state = null, 
                    error_code = null, 
                    last_synced_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    provider = null, 
                    link_tags = [
                        ''
                        ], 
                    tags = [
                        ''
                        ], 
                    webhook = '', 
                    products = null, 
                    available_products = [
                        'accounts'
                        ], )
            )
        else:
            return GetInvestmentTransactionsResponse(
                total = 56,
                page = 56,
                size = 56,
                investment_transactions = [
                    moneykit.models.investment_transaction_response.InvestmentTransactionResponse(
                        investment_transaction_id = '', 
                        account_id = '', 
                        amount = '', 
                        date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        description = '', 
                        type = '', 
                        fees = '', 
                        forex_rate = '', 
                        price = '', 
                        quantity = '', 
                        security_id = '', )
                    ],
                securities = [
                    moneykit.models.security_response.SecurityResponse(
                        security_id = '', 
                        name = '', 
                        type = '', 
                        currency = '', 
                        ticker = '', 
                        isin = '', 
                        sedol = '', 
                        close_price = '', 
                        close_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), )
                    ],
                accounts = [
                    moneykit.models.account_response.AccountResponse(
                        account_id = '', 
                        account_type = '', 
                        name = '', 
                        nickname = '', 
                        account_mask = '', 
                        balances = null, 
                        original_id = '', 
                        closed = True, )
                    ],
                link = moneykit.models.link_common.LinkCommon(
                    link_id = '', 
                    institution_id = '', 
                    institution_name = '', 
                    institution_avatar = '', 
                    state = null, 
                    error_code = null, 
                    last_synced_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    provider = null, 
                    link_tags = [
                        ''
                        ], 
                    tags = [
                        ''
                        ], 
                    webhook = '', 
                    products = null, 
                    available_products = [
                        'accounts'
                        ], ),
        )
        """

    def testGetInvestmentTransactionsResponse(self):
        """Test GetInvestmentTransactionsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictStr
from pydantic import Field
from moneykit.models.country import Country

try:
    from typing import Self
except ImportError:
    from typing_extensions import Self


class Institution(BaseModel):
    """
    Institution
    """  # noqa: E501

    institution_id: StrictStr = Field(
        description="MoneyKit's unique ID for this institution."
    )
    institution_id_aliases: List[StrictStr]
    name: StrictStr = Field(description="The name of the institution.")
    country: Country
    domain: Optional[StrictStr] = Field(
        default=None, description="The domain of the institution's user-facing website."
    )
    color: Optional[StrictStr] = Field(
        default=None,
        description="The primary color of this institution, represented as hexcode.",
    )
    color_dark: Optional[StrictStr] = Field(
        default=None,
        description="The dark-mode primary color of this institution, represented as hexcode.",
    )
    is_featured: StrictBool = Field(
        description="True for institutions that should be visually promoted to the end-user."
    )
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = [
        "institution_id",
        "institution_id_aliases",
        "name",
        "country",
        "domain",
        "color",
        "color_dark",
        "is_featured",
    ]

    model_config = {"populate_by_name": True, "validate_assignment": True}

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of Institution from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
                "additional_properties",
            },
            exclude_none=True,
        )
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of Institution from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "institution_id": obj.get("institution_id"),
                "institution_id_aliases": obj.get("institution_id_aliases"),
                "name": obj.get("name"),
                "country": obj.get("country"),
                "domain": obj.get("domain"),
                "color": obj.get("color"),
                "color_dark": obj.get("color_dark"),
                "is_featured": obj.get("is_featured"),
            }
        )
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.api.transactions_api import TransactionsApi


class TestTransactionsApi(unittest.TestCase):
    """TransactionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TransactionsApi()

    def tearDown(self) -> None:
        pass

    def test_correct_enrichment(self) -> None:
        """Test case for correct_enrichment

        /links/{id}/transactions/{txn_id}/enrichment
        """
        pass

    def test_get_transactions(self) -> None:
        """Test case for get_transactions

        /links/{id}/transactions
        """
        pass

    def test_get_transactions_sync(self) -> None:
        """Test case for get_transactions_sync

        /links/{id}/transactions/sync
        """
        pass

    def test_get_user_transactions(self) -> None:
        """Test case for get_user_transactions

        /users/{id}/transactions
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import json
import re  # noqa: F401
from enum import Enum


try:
    from typing import Self
except ImportError:
    from typing_extensions import Self


class BudSubcategory(str, Enum):
    """
    An enumeration.
    """

    """
    allowed enum values
    """
    ACCOUNT_FEES_AND_OTHER_BANK_CHARGES = "account_fees_and_other_bank_charges"
    ATM_FEES = "atm_fees"
    CASH_WITHDRAWALS = "cash_withdrawals"
    CURRENCY_EXCHANGE_AND_FEES = "currency_exchange_and_fees"
    INTEREST = "interest"
    NSF_AND_OVERDRAFT_FEES = "nsf_and_overdraft_fees"
    OTHER_BANKING = "other_banking"
    OUTGOING_CHECKS = "outgoing_checks"
    OVERDRAFT_PROTECTION = "overdraft_protection"
    REFUNDS_AND_REVERSALS = "refunds_and_reversals"
    UNPAID_TRANSACTIONS = "unpaid_transactions"
    BUY_NOW_PAY_LATER = "buy_now_pay_later"
    CAR_PAYMENT = "car_payment"
    CASH_ADVANCE_LOANS = "cash_advance_loans"
    CREDIT_CARDS = "credit_cards"
    DEBT_MANAGEMENT = "debt_management"
    LOAN_INCOMING = "loan_incoming"
    LOAN_REPAYMENT = "loan_repayment"
    OTHER_BORROWING_AND_LOANS = "other_borrowing_and_loans"
    STUDENT_LOAN = "student_loan"
    VEHICLE_LOAN = "vehicle_loan"
    CHARITY = "charity"
    OTHER_CHARITY = "other_charity"
    CHILD_SUPPORT = "child_support"
    CHILDCARE = "childcare"
    CHILDRENS_EXPENSES = "childrens_expenses"
    OTHER_DEPENDENT_COSTS = "other_dependent_costs"
    DRIVING_LESSONS = "driving_lessons"
    OTHER_EDUCATION = "other_education"
    UNIVERSITY_AND_TUITION = "university_and_tuition"
    BOOKS_AND_READING = "books_and_reading"
    CINEMA = "cinema"
    GAMING = "gaming"
    LEISURE_AND_AMUSEMENT_ACTIVITIES = "leisure_and_amusement_activities"
    OTHER_ENTERTAINMENT = "other_entertainment"
    OTHER_EVENTS = "other_events"
    SPORT_EVENTS = "sport_events"
    THEATRE_CONCERTS_AND_TICKETS = "theatre_concerts_and_tickets"
    BUSINESS_EXPENSES = "business_expenses"
    FINANCIAL_AND_LEGAL_EXPENSES = "financial_and_legal_expenses"
    OTHER_EXPENSES = "other_expenses"
    OTHER_MEMBERSHIPS_AND_SERVICES = "other_memberships_and_services"
    POSTAGE_AND_OFFICE_SUPPLIES = "postage_and_office_supplies"
    BARS_AND_PUBS = "bars_and_pubs"
    COFFEE = "coffee"
    CONVENIENCE_STORES = "convenience_stores"
    EATING_OUT_AND_TAKEAWAYS = "eating_out_and_takeaways"
    GROCERIES = "groceries"
    OTHER_EATING_OUT = "other_eating_out"
    OTHER_FOOD_AND_DRINK = "other_food_and_drink"
    SPECIALITY_FOOD_AND_DRINK = "speciality_food_and_drink"
    GAMBLING_AND_BETTING = "gambling_and_betting"
    LOTTERIES_AND_SWEEPSTAKES = "lotteries_and_sweepstakes"
    OTHER_GAMBLING_AND_LOTTERIES = "other_gambling_and_lotteries"
    OTHER_GENERAL = "other_general"
    BEAUTY = "beauty"
    DENTAL = "dental"
    GYM_AND_FITNESS = "gym_and_fitness"
    HEALTHCARE = "healthcare"
    OTHER_HEALTH_AND_PERSONAL_CARE = "other_health_and_personal_care"
    OPTICAL = "optical"
    PHARMACIES_AND_HEALTH_PRODUCTS = "pharmacies_and_health_products"
    SPORT_ACCESSORIES_AND_EQUIPMENT = "sport_accessories_and_equipment"
    FURNITURE = "furniture"
    GARDENING = "gardening"
    HOME_MAINTENANCE = "home_maintenance"
    HOUSEHOLD_GOODS = "household_goods"
    LAUNDRY = "laundry"
    OTHER_HOME = "other_home"
    PETS = "pets"
    BENEFITS_AND_SOCIAL_SECURITY = "benefits_and_social_security"
    CHILD_SUPPORT_INCOME = "child_support_income"
    CRYPTO_PLATFORM_INCOMING = "crypto_platform_incoming"
    DEPOSITS = "deposits"
    EMPLOYMENT_INCOME = "employment_income"
    INVESTMENT_INCOME = "investment_income"
    OTHER_INCOME = "other_income"
    PENSION_INCOME = "pension_income"
    RENTAL_INCOME = "rental_income"
    BUSINESS_INSURANCE = "business_insurance"
    HEALTH_AND_LIFE_INSURANCE = "health_and_life_insurance"
    HOME_INSURANCE = "home_insurance"
    OTHER_INSURANCE = "other_insurance"
    PET_INSURANCE = "pet_insurance"
    TRAVEL_INSURANCE = "travel_insurance"
    VEHICLE_INSURANCE = "vehicle_insurance"
    BROADBAND_PHONE_TV = "broadband_phone_tv"
    DIGITAL_MEDIA_AND_SOFTWARE = "digital_media_and_software"
    OTHER_MEDIA_AND_TELECOMS = "other_media_and_telecoms"
    TV_STREAMING_SERVICES = "tv_streaming_services"
    MORTGAGE = "mortgage"
    OTHER_MORTGAGE_AND_RENT = "other_mortgage_and_rent"
    RENT = "rent"
    CRYPTO_PLATFORM_OUTGOING = "crypto_platform_outgoing"
    INVESTMENTS = "investments"
    PENSIONS = "pensions"
    OTHER_PENSIONS_SAVINGS_AND_INVESTMENTS = "other_pensions_savings_and_investments"
    SAVINGS = "savings"
    CLOTHING_AND_ACCESSORIES = "clothing_and_accessories"
    DEPARTMENT_STORES = "department_stores"
    ELECTRONICS_APPLIANCES_AND_TECHNOLOGY = "electronics_appliances_and_technology"
    FLOWERS_AND_GIFTS = "flowers_and_gifts"
    GENERAL_ONLINE_SHOPPING = "general_online_shopping"
    HOBBIES = "hobbies"
    OTHER_SHOPPING = "other_shopping"
    SMOKING_AND_VAPING = "smoking_and_vaping"
    FEDERAL_TAX = "federal_tax"
    OTHER_TAXES = "other_taxes"
    INTERNAL_TRANSFERS = "internal_transfers"
    OTHER_TRANSFERS = "other_transfers"
    TRANSFERS_IN = "transfers_in"
    TRANSFERS_OUT = "transfers_out"
    OTHER_TRANSPORT = "other_transport"
    PARKING_AND_TOLLS = "parking_and_tolls"
    PUBLIC_TRANSPORT = "public_transport"
    TAXI = "taxi"
    VEHICLE = "vehicle"
    VEHICLE_FUEL_AND_CHARGING = "vehicle_fuel_and_charging"
    VEHICLE_RENTAL = "vehicle_rental"
    PETROL_AND_VEHICLE_CHARGING = "petrol_and_vehicle_charging"
    FLIGHTS_AND_AIRPORT_EXPENSES = "flights_and_airport_expenses"
    HOLIDAY_AND_TRAVEL_EXPENSES = "holiday_and_travel_expenses"
    OTHER_TRAVEL = "other_travel"
    OTHER_UTILITIES = "other_utilities"
    UTILITIES_ENERGY = "utilities_energy"
    UTILITIES_WATER_AND_SEWAGE = "utilities_water_and_sewage"
    WASTE_AND_RECYCLING = "waste_and_recycling"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of BudSubcategory from a JSON string"""
        return cls(json.loads(json_str))



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.transaction_sync import TransactionSync


class TestTransactionSync(unittest.TestCase):
    """TransactionSync unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TransactionSync:
        """Test TransactionSync
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `TransactionSync`
        """
        model = TransactionSync()
        if include_optional:
            return TransactionSync(
                created = [
                    moneykit.models.transaction_response.TransactionResponse(
                        transaction_id = '', 
                        account_id = '', 
                        amount = '', 
                        type = null, 
                        currency = '', 
                        date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        description = '', 
                        raw_description = '', 
                        pending = True, 
                        category = '', 
                        enrichment = moneykit.models.transaction_enrichment_response.TransactionEnrichmentResponse(
                            category = moneykit.models.transaction_category_response.TransactionCategoryResponse(
                                value = '', 
                                confidence = 56, ), 
                            subcategory = moneykit.models.transaction_subcategory_response.TransactionSubcategoryResponse(
                                value = '', 
                                confidence = 56, ), 
                            merchant = moneykit.models.transaction_merchant_response.TransactionMerchantResponse(
                                id = '', 
                                name = '', 
                                logo = '', 
                                confidence = 56, ), 
                            processor = moneykit.models.transaction_processor_response.TransactionProcessorResponse(
                                id = '', 
                                name = '', 
                                logo = '', 
                                confidence = 56, ), 
                            recurrence = moneykit.models.transaction_recurrence_response.TransactionRecurrenceResponse(
                                frequency = '', 
                                next_predicted_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), ), ), 
                        original_id = '', )
                    ],
                updated = [
                    moneykit.models.transaction_response.TransactionResponse(
                        transaction_id = '', 
                        account_id = '', 
                        amount = '', 
                        type = null, 
                        currency = '', 
                        date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        description = '', 
                        raw_description = '', 
                        pending = True, 
                        category = '', 
                        enrichment = moneykit.models.transaction_enrichment_response.TransactionEnrichmentResponse(
                            category = moneykit.models.transaction_category_response.TransactionCategoryResponse(
                                value = '', 
                                confidence = 56, ), 
                            subcategory = moneykit.models.transaction_subcategory_response.TransactionSubcategoryResponse(
                                value = '', 
                                confidence = 56, ), 
                            merchant = moneykit.models.transaction_merchant_response.TransactionMerchantResponse(
                                id = '', 
                                name = '', 
                                logo = '', 
                                confidence = 56, ), 
                            processor = moneykit.models.transaction_processor_response.TransactionProcessorResponse(
                                id = '', 
                                name = '', 
                                logo = '', 
                                confidence = 56, ), 
                            recurrence = moneykit.models.transaction_recurrence_response.TransactionRecurrenceResponse(
                                frequency = '', 
                                next_predicted_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), ), ), 
                        original_id = '', )
                    ],
                removed = [
                    ''
                    ]
            )
        else:
            return TransactionSync(
                created = [
                    moneykit.models.transaction_response.TransactionResponse(
                        transaction_id = '', 
                        account_id = '', 
                        amount = '', 
                        type = null, 
                        currency = '', 
                        date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        description = '', 
                        raw_description = '', 
                        pending = True, 
                        category = '', 
                        enrichment = moneykit.models.transaction_enrichment_response.TransactionEnrichmentResponse(
                            category = moneykit.models.transaction_category_response.TransactionCategoryResponse(
                                value = '', 
                                confidence = 56, ), 
                            subcategory = moneykit.models.transaction_subcategory_response.TransactionSubcategoryResponse(
                                value = '', 
                                confidence = 56, ), 
                            merchant = moneykit.models.transaction_merchant_response.TransactionMerchantResponse(
                                id = '', 
                                name = '', 
                                logo = '', 
                                confidence = 56, ), 
                            processor = moneykit.models.transaction_processor_response.TransactionProcessorResponse(
                                id = '', 
                                name = '', 
                                logo = '', 
                                confidence = 56, ), 
                            recurrence = moneykit.models.transaction_recurrence_response.TransactionRecurrenceResponse(
                                frequency = '', 
                                next_predicted_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), ), ), 
                        original_id = '', )
                    ],
                updated = [
                    moneykit.models.transaction_response.TransactionResponse(
                        transaction_id = '', 
                        account_id = '', 
                        amount = '', 
                        type = null, 
                        currency = '', 
                        date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), 
                        datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        description = '', 
                        raw_description = '', 
                        pending = True, 
                        category = '', 
                        enrichment = moneykit.models.transaction_enrichment_response.TransactionEnrichmentResponse(
                            category = moneykit.models.transaction_category_response.TransactionCategoryResponse(
                                value = '', 
                                confidence = 56, ), 
                            subcategory = moneykit.models.transaction_subcategory_response.TransactionSubcategoryResponse(
                                value = '', 
                                confidence = 56, ), 
                            merchant = moneykit.models.transaction_merchant_response.TransactionMerchantResponse(
                                id = '', 
                                name = '', 
                                logo = '', 
                                confidence = 56, ), 
                            processor = moneykit.models.transaction_processor_response.TransactionProcessorResponse(
                                id = '', 
                                name = '', 
                                logo = '', 
                                confidence = 56, ), 
                            recurrence = moneykit.models.transaction_recurrence_response.TransactionRecurrenceResponse(
                                frequency = '', 
                                next_predicted_date = datetime.datetime.strptime('1975-12-30', '%Y-%m-%d').date(), ), ), 
                        original_id = '', )
                    ],
                removed = [
                    ''
                    ],
        )
        """

    def testTransactionSync(self):
        """Test TransactionSync"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
MoneyKit API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 2023-02-18
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from moneykit.models.http_validation_error import HTTPValidationError


class TestHTTPValidationError(unittest.TestCase):
    """HTTPValidationError unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> HTTPValidationError:
        """Test HTTPValidationError
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `HTTPValidationError`
        """
        model = HTTPValidationError()
        if include_optional:
            return HTTPValidationError(
                error_code = 'api_error.request.validation_failed',
                error_message = 'Request validation error',
                documentation_url = '',
                validation_errors = [
                    moneykit.models.validation_error.ValidationError(
                        location = [
                            null
                            ], 
                        message = '', 
                        type = '', )
                    ]
            )
        else:
            return HTTPValidationError(
                validation_errors = [
                    moneykit.models.validation_error.ValidationError(
                        location = [
                            null
                            ], 
                        message = '', 
                        type = '', )
                    ],
        )
        """

    def testHTTPValidationError(self):
        """Test HTTPValidationError"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
